@@ -338,11 +338,7 @@ _source_functions = {'google': _get_hist_google, 'yahoo': _get_hist_yahoo}
 
 
 def _get_data_from(symbols, start, end, retry_count, pause, adjust_price,
-                   ret_index, chunksize, source, name):
-    if name is not None:
-        warnings.warn("Arg 'name' is deprecated, please use 'symbols' "
-                      "instead.", FutureWarning)
-        symbols = name
+                   ret_index, chunksize, source):
 
     src_fn = _source_functions[source]
 
@@ -367,7 +363,7 @@ def _get_data_from(symbols, start, end, retry_count, pause, adjust_price,
 
 def get_data_yahoo(symbols=None, start=None, end=None, retry_count=3,
                    pause=0.001, adjust_price=False, ret_index=False,
-                   chunksize=25, name=None):
+                   chunksize=25):
     """
     Returns DataFrame/Panel of historical stock prices from symbols, over date
     range, start to end. To avoid being penalized by Yahoo! Finance servers,
@@ -402,12 +398,12 @@ def get_data_yahoo(symbols=None, start=None, end=None, retry_count=3,
     hist_data : DataFrame (str) or Panel (array-like object, DataFrame)
     """
     return _get_data_from(symbols, start, end, retry_count, pause,
-                          adjust_price, ret_index, chunksize, 'yahoo', name)
+                          adjust_price, ret_index, chunksize, 'yahoo')
 
 
 def get_data_google(symbols=None, start=None, end=None, retry_count=3,
                     pause=0.001, adjust_price=False, ret_index=False,
-                    chunksize=25, name=None):
+                    chunksize=25):
     """
     Returns DataFrame/Panel of historical stock prices from symbols, over date
     range, start to end. To avoid being penalized by Google Finance servers,
@@ -436,7 +432,7 @@ def get_data_google(symbols=None, start=None, end=None, retry_count=3,
     hist_data : DataFrame (str) or Panel (array-like object, DataFrame)
     """
     return _get_data_from(symbols, start, end, retry_count, pause,
-                          adjust_price, ret_index, chunksize, 'google', name)
+                          adjust_price, ret_index, chunksize, 'google')
 
 
 _FRED_URL = "http://research.stlouisfed.org/fred2/series/"
@@ -494,7 +490,7 @@ def get_data_famafrench(name):
         tmpf.write(raw)
 
         with ZipFile(tmpf, 'r') as zf:
-            data = zf.open(name + '.txt').readlines()
+            data = zf.open(zf.namelist()[0]).readlines()
 
     line_lengths = np.array(lmap(len, data))
     file_edges = np.where(line_lengths == 2)[0]
