@@ -1,11 +1,16 @@
+import operator
+from pandas.compat import reduce
 from pandas.core.index import Index
 import numpy as np
+from pandas import algos
+
 
 def match(needles, haystack):
     haystack = Index(haystack)
     needles = Index(needles)
     return haystack.get_indexer(needles)
 
+
 def cartesian_product(X):
     '''
     Numpy version of itertools.product or pandas.compat.product.
@@ -15,7 +20,7 @@ def cartesian_product(X):
     --------
     >>> cartesian_product([list('ABC'), [1, 2]])
     [array(['A', 'A', 'B', 'B', 'C', 'C'], dtype='|S1'),
- 	array([1, 2, 1, 2, 1, 2])]
+    array([1, 2, 1, 2, 1, 2])]
 
     '''
 
@@ -27,6 +32,17 @@ def cartesian_product(X):
 
     b = cumprodX[-1] / cumprodX
 
-    return [np.tile(np.repeat(x, b[i]), 
+    return [np.tile(np.repeat(np.asarray(x), b[i]),
                     np.product(a[i]))
-               for i, x in enumerate(X)]
\ No newline at end of file
+               for i, x in enumerate(X)]
+
+
+def _compose2(f, g):
+    """Compose 2 callables"""
+    return lambda *args, **kwargs: f(g(*args, **kwargs))
+
+
+def compose(*funcs):
+    """Compose 2 or more callables"""
+    assert len(funcs) > 1, 'At least 2 callables must be passed to compose'
+    return reduce(_compose2, funcs)
