@@ -9,12 +9,13 @@ import numpy as np
 from pandas.core.common import (isnull, _NS_DTYPE, _INT64_DTYPE,
                                 is_list_like,_values_from_object, _maybe_box,
                                 notnull, ABCSeries)
-from pandas.core.index import Index, Int64Index, _Identity
+from pandas.core.index import Index, Int64Index, _Identity, Float64Index
 import pandas.compat as compat
 from pandas.compat import u
 from pandas.tseries.frequencies import (
     infer_freq, to_offset, get_period_alias,
-    Resolution, get_reso_string)
+    Resolution, get_reso_string, get_offset)
+from pandas.core.base import DatetimeIndexOpsMixin
 from pandas.tseries.offsets import DateOffset, generate_range, Tick, CDay
 from pandas.tseries.tools import parse_time_string, normalize_date
 from pandas.util.decorators import cache_readonly
@@ -28,6 +29,7 @@ import pandas.tslib as tslib
 import pandas.algos as _algos
 import pandas.index as _index
 
+from pandas.tslib import isleapyear
 
 def _utc():
     import pytz
@@ -43,7 +45,14 @@ def _field_accessor(name, field, docstring=None):
             utc = _utc()
             if self.tz is not utc:
                 values = self._local_timestamps()
-        return tslib.get_date_field(values, field)
+        if field in ['is_month_start', 'is_month_end',
+                    'is_quarter_start', 'is_quarter_end',
+                    'is_year_start', 'is_year_end']:
+            month_kw = self.freq.kwds.get('startingMonth', self.freq.kwds.get('month', 12)) if self.freq else 12
+            freqstr = self.freqstr if self.freq else None
+            return tslib.get_start_end_field(values, field, freqstr, month_kw)
+        else:
+            return tslib.get_date_field(values, field)
     f.__name__ = name
     f.__doc__ = docstring
     return property(f)
@@ -94,7 +103,7 @@ def _ensure_datetime64(other):
 
 _midnight = time(0, 0)
 
-class DatetimeIndex(Int64Index):
+class DatetimeIndex(DatetimeIndexOpsMixin, Int64Index):
     """
     Immutable ndarray of datetime64 data, represented internally as int64, and
     which can be boxed to Timestamp objects that are subclasses of datetime and
@@ -144,8 +153,10 @@ class DatetimeIndex(Int64Index):
 
     _engine_type = _index.DatetimeEngine
 
+    tz = None
     offset = None
     _comparables = ['name','freqstr','tz']
+    _allow_datetime_index_ops = True
 
     def __new__(cls, data=None,
                 freq=None, start=None, end=None, periods=None,
@@ -156,10 +167,6 @@ class DatetimeIndex(Int64Index):
         dayfirst = kwds.pop('dayfirst', None)
         yearfirst = kwds.pop('yearfirst', None)
         infer_dst = kwds.pop('infer_dst', False)
-        warn = False
-        if 'offset' in kwds and kwds['offset']:
-            freq = kwds['offset']
-            warn = True
 
         freq_infer = False
         if not isinstance(freq, DateOffset):
@@ -171,14 +178,6 @@ class DatetimeIndex(Int64Index):
                 freq_infer = True
                 freq = None
 
-        if warn:
-            import warnings
-            warnings.warn("parameter 'offset' is deprecated, "
-                          "please use 'freq' instead",
-                          FutureWarning)
-
-        offset = freq
-
         if periods is not None:
             if com.is_float(periods):
                 periods = int(periods)
@@ -186,12 +185,12 @@ class DatetimeIndex(Int64Index):
                 raise ValueError('Periods must be a number, got %s' %
                                  str(periods))
 
-        if data is None and offset is None:
+        if data is None and freq is None:
             raise ValueError("Must provide freq argument if no data is "
                              "supplied")
 
         if data is None:
-            return cls._generate(start, end, periods, name, offset,
+            return cls._generate(start, end, periods, name, freq,
                                  tz=tz, normalize=normalize, closed=closed,
                                  infer_dst=infer_dst)
 
@@ -209,11 +208,11 @@ class DatetimeIndex(Int64Index):
 
             # try a few ways to make it datetime64
             if lib.is_string_array(data):
-                data = _str_to_dt_array(data, offset, dayfirst=dayfirst,
+                data = _str_to_dt_array(data, freq, dayfirst=dayfirst,
                                         yearfirst=yearfirst)
             else:
                 data = tools.to_datetime(data, errors='raise')
-                data.offset = offset
+                data.offset = freq
                 if isinstance(data, DatetimeIndex):
                     if name is not None:
                         data.name = name
@@ -224,7 +223,7 @@ class DatetimeIndex(Int64Index):
                     return data
 
         if issubclass(data.dtype.type, compat.string_types):
-            data = _str_to_dt_array(data, offset, dayfirst=dayfirst,
+            data = _str_to_dt_array(data, freq, dayfirst=dayfirst,
                                       yearfirst=yearfirst)
 
         if issubclass(data.dtype.type, np.datetime64):
@@ -236,8 +235,8 @@ class DatetimeIndex(Int64Index):
 
                 subarr = data.values
 
-                if offset is None:
-                    offset = data.offset
+                if freq is None:
+                    freq = data.offset
                     verify_integrity = False
             else:
                 if data.dtype != _NS_DTYPE:
@@ -252,15 +251,29 @@ class DatetimeIndex(Int64Index):
             else:
                 subarr = data.view(_NS_DTYPE)
         else:
-            try:
-                subarr = tools.to_datetime(data, box=False)
-            except ValueError:
-                # tz aware
-                subarr = tools.to_datetime(data, box=False, utc=True)
+            if isinstance(data, ABCSeries):
+                values = data.values
+            else:
+                values = data
 
-            if not np.issubdtype(subarr.dtype, np.datetime64):
-                raise ValueError('Unable to convert %s to datetime dtype'
-                                 % str(data))
+            if lib.is_string_array(values):
+                subarr = _str_to_dt_array(values, freq, dayfirst=dayfirst,
+                                        yearfirst=yearfirst)
+            else:
+                try:
+                    subarr = tools.to_datetime(data, box=False)
+
+                    # make sure that we have a index/ndarray like (and not a Series)
+                    if isinstance(subarr, ABCSeries):
+                        subarr = subarr.values
+
+                except ValueError:
+                    # tz aware
+                    subarr = tools.to_datetime(data, box=False, utc=True)
+
+                if not np.issubdtype(subarr.dtype, np.datetime64):
+                    raise ValueError('Unable to convert %s to datetime dtype'
+                                     % str(data))
 
         if isinstance(subarr, DatetimeIndex):
             if tz is None:
@@ -280,15 +293,17 @@ class DatetimeIndex(Int64Index):
 
         subarr = subarr.view(cls)
         subarr.name = name
-        subarr.offset = offset
+        subarr.offset = freq
         subarr.tz = tz
 
         if verify_integrity and len(subarr) > 0:
-            if offset is not None and not freq_infer:
+            if freq is not None and not freq_infer:
                 inferred = subarr.inferred_freq
-                if inferred != offset.freqstr:
-                    raise ValueError('Dates do not conform to passed '
-                                     'frequency')
+                if inferred != freq.freqstr:
+                    on_freq = cls._generate(subarr[0], None, len(subarr), None, freq, tz=tz)
+                    if not np.array_equal(subarr.asi8, on_freq.asi8):
+                        raise ValueError('Inferred frequency {0} from passed dates does not'
+                                         'conform to passed frequency {1}'.format(inferred, freq.freqstr))
 
         if freq_infer:
             inferred = subarr.inferred_freq
@@ -336,7 +351,9 @@ class DatetimeIndex(Int64Index):
                              'different timezones')
 
         inferred_tz = tools._maybe_get_tz(inferred_tz)
-        tz = tools._maybe_get_tz(tz)
+
+        # these may need to be localized
+        tz = tools._maybe_get_tz(tz, start or end)
 
         if tz is not None and inferred_tz is not None:
             if not inferred_tz == tz:
@@ -616,18 +633,19 @@ class DatetimeIndex(Int64Index):
     def _add_delta(self, delta):
         if isinstance(delta, (Tick, timedelta)):
             inc = offsets._delta_to_nanoseconds(delta)
+            mask = self.asi8 == tslib.iNaT
             new_values = (self.asi8 + inc).view(_NS_DTYPE)
-            tz = 'UTC' if self.tz is not None else None
-            result = DatetimeIndex(new_values, tz=tz, freq='infer')
-            utc = _utc()
-            if self.tz is not None and self.tz is not utc:
-                result = result.tz_convert(self.tz)
+            new_values[mask] = tslib.iNaT
+            new_values = new_values.view(_NS_DTYPE)
         elif isinstance(delta, np.timedelta64):
             new_values = self.to_series() + delta
-            result = DatetimeIndex(new_values, tz=self.tz, freq='infer')
         else:
             new_values = self.astype('O') + delta
-            result = DatetimeIndex(new_values, tz=self.tz, freq='infer')
+        tz = 'UTC' if self.tz is not None else None
+        result = DatetimeIndex(new_values, tz=tz, freq='infer')
+        utc = _utc()
+        if self.tz is not None and self.tz is not utc:
+            result = result.tz_convert(self.tz)
         return result
 
     def __contains__(self, key):
@@ -715,6 +733,38 @@ class DatetimeIndex(Int64Index):
             values = self._local_timestamps()
         return tslib.get_time_micros(values)
 
+    def to_series(self, keep_tz=False):
+        """
+        Create a Series with both index and values equal to the index keys
+        useful with map for returning an indexer based on an index
+
+        Parameters
+        ----------
+        keep_tz : optional, defaults False.
+                  return the data keeping the timezone.
+
+                  If keep_tz is True:
+
+                    If the timezone is not set or is UTC, the resulting
+                    Series will have a datetime64[ns] dtype.
+                    Otherwise the Series will have an object dtype.
+
+                  If keep_tz is False:
+
+                    Series will have a datetime64[ns] dtype.
+
+        Returns
+        -------
+        Series
+        """
+        return super(DatetimeIndex, self).to_series(keep_tz=keep_tz)
+
+    def _to_embed(self, keep_tz=False):
+        """ return an array repr of this object, potentially casting to object """
+        if keep_tz and self.tz is not None and str(self.tz) != 'UTC':
+            return self.asobject.values
+        return self.values
+
     @property
     def asobject(self):
         """
@@ -1028,7 +1078,13 @@ class DatetimeIndex(Int64Index):
         left_end = left[-1]
 
         # Only need to "adjoin", not overlap
-        return (right_start == left_end + offset) or right_start in left
+        try:
+            return (right_start == left_end + offset) or right_start in left
+        except (ValueError):
+
+            # if we are comparing an offset that does not propogate timezones
+            # this will raise
+            return False
 
     def _fast_union(self, other):
         if len(other) == 0:
@@ -1200,16 +1256,14 @@ class DatetimeIndex(Int64Index):
         Fast lookup of value from 1-dimensional ndarray. Only use this if you
         know what you're doing
         """
-        timestamp = None
-        #if isinstance(key, Timestamp):
-        #    timestamp = key
-        #el
-        if isinstance(key, datetime):
-            # needed to localize naive datetimes
-            timestamp = Timestamp(key, tz=self.tz)
 
-        if timestamp:
-            return self.get_value_maybe_box(series, timestamp)
+        if isinstance(key, datetime):
+
+            # needed to localize naive datetimes
+            if self.tz is not None:
+                key = Timestamp(key, tz=self.tz)
+
+            return self.get_value_maybe_box(series, key)
 
         try:
             return _maybe_box(self, Index.get_value(self, series, key), series, key)
@@ -1363,8 +1417,6 @@ class DatetimeIndex(Int64Index):
 
             return self._simple_new(result, self.name, new_offset, self.tz)
 
-    _getitem_slice = __getitem__
-
     # Try to run function on index first, and then on elements of index
     # Especially important for group-by functionality
     def map(self, f):
@@ -1379,6 +1431,7 @@ class DatetimeIndex(Int64Index):
     # alias to offset
     @property
     def freq(self):
+        """ return the frequency object if its set, otherwise None """
         return self.offset
 
     @cache_readonly
@@ -1390,26 +1443,33 @@ class DatetimeIndex(Int64Index):
 
     @property
     def freqstr(self):
+        """ return the frequency object as a string if its set, otherwise None """
         return self.offset.freqstr
 
-    year = _field_accessor('year', 'Y')
-    month = _field_accessor('month', 'M', "The month as January=1, December=12")
-    day = _field_accessor('day', 'D')
-    hour = _field_accessor('hour', 'h')
-    minute = _field_accessor('minute', 'm')
-    second = _field_accessor('second', 's')
-    microsecond = _field_accessor('microsecond', 'us')
-    nanosecond = _field_accessor('nanosecond', 'ns')
-    weekofyear = _field_accessor('weekofyear', 'woy')
-    week = weekofyear
-    dayofweek = _field_accessor('dayofweek', 'dow',
-                                "The day of the week with Monday=0, Sunday=6")
-    weekday = dayofweek
-    dayofyear = _field_accessor('dayofyear', 'doy')
-    quarter = _field_accessor('quarter', 'q')
+    _year = _field_accessor('year', 'Y')
+    _month = _field_accessor('month', 'M', "The month as January=1, December=12")
+    _day = _field_accessor('day', 'D')
+    _hour = _field_accessor('hour', 'h')
+    _minute = _field_accessor('minute', 'm')
+    _second = _field_accessor('second', 's')
+    _microsecond = _field_accessor('microsecond', 'us')
+    _nanosecond = _field_accessor('nanosecond', 'ns')
+    _weekofyear = _field_accessor('weekofyear', 'woy')
+    _week = _weekofyear
+    _dayofweek = _field_accessor('dayofweek', 'dow',
+                                 "The day of the week with Monday=0, Sunday=6")
+    _weekday = _dayofweek
+    _dayofyear = _field_accessor('dayofyear', 'doy')
+    _quarter = _field_accessor('quarter', 'q')
+    _is_month_start = _field_accessor('is_month_start', 'is_month_start')
+    _is_month_end = _field_accessor('is_month_end', 'is_month_end')
+    _is_quarter_start = _field_accessor('is_quarter_start', 'is_quarter_start')
+    _is_quarter_end = _field_accessor('is_quarter_end', 'is_quarter_end')
+    _is_year_start = _field_accessor('is_year_start', 'is_year_start')
+    _is_year_end = _field_accessor('is_year_end', 'is_year_end')
 
     @property
-    def time(self):
+    def _time(self):
         """
         Returns numpy array of datetime.time. The time part of the Timestamps.
         """
@@ -1418,7 +1478,7 @@ class DatetimeIndex(Int64Index):
         return _algos.arrmap_object(self.asobject, lambda x: x.time())
 
     @property
-    def date(self):
+    def _date(self):
         """
         Returns numpy array of datetime.date. The date part of the Timestamps.
         """
@@ -1714,6 +1774,34 @@ class DatetimeIndex(Int64Index):
             max_stamp = self.asi8.max()
             return Timestamp(max_stamp, tz=self.tz)
 
+    def to_julian_date(self):
+        """
+        Convert DatetimeIndex to Float64Index of Julian Dates.
+        0 Julian date is noon January 1, 4713 BC.
+        http://en.wikipedia.org/wiki/Julian_day
+        """
+
+        # http://mysite.verizon.net/aesir_research/date/jdalg2.htm
+        year = self.year
+        month = self.month
+        day = self.day
+        testarr = month < 3
+        year[testarr] -= 1
+        month[testarr] += 12
+        return Float64Index(day +
+                            np.fix((153*month - 457)/5) +
+                            365*year +
+                            np.floor(year / 4) -
+                            np.floor(year / 100) +
+                            np.floor(year / 400) +
+                            1721118.5 +
+                            (self.hour +
+                             self.minute/60.0 +
+                             self.second/3600.0 +
+                             self.microsecond/3600.0/1e+6 +
+                             self.nanosecond/3600.0/1e+9
+                            )/24.0)
+
 
 def _generate_regular_range(start, end, periods, offset):
     if isinstance(offset, Tick):
@@ -1772,7 +1860,7 @@ def date_range(start=None, end=None, periods=None, freq='D', tz=None,
         Frequency strings can have multiples, e.g. '5H'
     tz : string or None
         Time zone name for returning localized DatetimeIndex, for example
-        Asia/Hong_Kong
+    Asia/Hong_Kong
     normalize : bool, default False
         Normalize start/end dates to midnight before generating date range
     name : str, default None
