@@ -42,13 +42,13 @@ class TestGenRangeGeneration(tm.TestCase):
     def test_generate(self):
         rng1 = list(generate_range(START, END, offset=datetools.bday))
         rng2 = list(generate_range(START, END, time_rule='B'))
-        self.assert_(np.array_equal(rng1, rng2))
+        self.assert_numpy_array_equal(rng1, rng2)
 
     def test_generate_cday(self):
         _skip_if_no_cday()
         rng1 = list(generate_range(START, END, offset=datetools.cday))
         rng2 = list(generate_range(START, END, time_rule='C'))
-        self.assert_(np.array_equal(rng1, rng2))
+        self.assert_numpy_array_equal(rng1, rng2)
 
     def test_1(self):
         eq_gen_range(dict(start=datetime(2009, 3, 25), periods=2),
@@ -107,8 +107,8 @@ class TestDateRange(tm.TestCase):
     def test_cached_range_bug(self):
         rng = date_range('2010-09-01 05:00:00', periods=50,
                          freq=datetools.DateOffset(hours=6))
-        self.assertEquals(len(rng), 50)
-        self.assertEquals(rng[0], datetime(2010, 9, 1, 5))
+        self.assertEqual(len(rng), 50)
+        self.assertEqual(rng[0], datetime(2010, 9, 1, 5))
 
     def test_timezone_comparaison_bug(self):
         start = Timestamp('20130220 10:00', tz='US/Eastern')
@@ -125,13 +125,13 @@ class TestDateRange(tm.TestCase):
         d = self.rng[10]
 
         comp = self.rng > d
-        self.assert_(comp[11])
-        self.assert_(not comp[9])
+        self.assertTrue(comp[11])
+        self.assertFalse(comp[9])
 
     def test_copy(self):
         cp = self.rng.copy()
         repr(cp)
-        self.assert_(cp.equals(self.rng))
+        self.assertTrue(cp.equals(self.rng))
 
     def test_repr(self):
         # only really care that it works
@@ -139,47 +139,47 @@ class TestDateRange(tm.TestCase):
 
     def test_getitem(self):
         smaller = self.rng[:5]
-        self.assert_(np.array_equal(smaller, self.rng.view(np.ndarray)[:5]))
-        self.assertEquals(smaller.offset, self.rng.offset)
+        self.assert_numpy_array_equal(smaller, self.rng.view(np.ndarray)[:5])
+        self.assertEqual(smaller.offset, self.rng.offset)
 
         sliced = self.rng[::5]
-        self.assertEquals(sliced.offset, datetools.bday * 5)
+        self.assertEqual(sliced.offset, datetools.bday * 5)
 
         fancy_indexed = self.rng[[4, 3, 2, 1, 0]]
-        self.assertEquals(len(fancy_indexed), 5)
+        self.assertEqual(len(fancy_indexed), 5)
         tm.assert_isinstance(fancy_indexed, DatetimeIndex)
-        self.assert_(fancy_indexed.freq is None)
+        self.assertIsNone(fancy_indexed.freq)
 
         # 32-bit vs. 64-bit platforms
-        self.assertEquals(self.rng[4], self.rng[np.int_(4)])
+        self.assertEqual(self.rng[4], self.rng[np.int_(4)])
 
     def test_getitem_matplotlib_hackaround(self):
         values = self.rng[:, None]
         expected = self.rng.values[:, None]
-        self.assert_(np.array_equal(values, expected))
+        self.assert_numpy_array_equal(values, expected)
 
     def test_shift(self):
         shifted = self.rng.shift(5)
-        self.assertEquals(shifted[0], self.rng[5])
-        self.assertEquals(shifted.offset, self.rng.offset)
+        self.assertEqual(shifted[0], self.rng[5])
+        self.assertEqual(shifted.offset, self.rng.offset)
 
         shifted = self.rng.shift(-5)
-        self.assertEquals(shifted[5], self.rng[0])
-        self.assertEquals(shifted.offset, self.rng.offset)
+        self.assertEqual(shifted[5], self.rng[0])
+        self.assertEqual(shifted.offset, self.rng.offset)
 
         shifted = self.rng.shift(0)
-        self.assertEquals(shifted[0], self.rng[0])
-        self.assertEquals(shifted.offset, self.rng.offset)
+        self.assertEqual(shifted[0], self.rng[0])
+        self.assertEqual(shifted.offset, self.rng.offset)
 
         rng = date_range(START, END, freq=datetools.bmonthEnd)
         shifted = rng.shift(1, freq=datetools.bday)
-        self.assertEquals(shifted[0], rng[0] + datetools.bday)
+        self.assertEqual(shifted[0], rng[0] + datetools.bday)
 
     def test_pickle_unpickle(self):
         pickled = pickle.dumps(self.rng)
         unpickled = pickle.loads(pickled)
 
-        self.assert_(unpickled.offset is not None)
+        self.assertIsNotNone(unpickled.offset)
 
     def test_union(self):
         # overlapping
@@ -204,7 +204,7 @@ class TestDateRange(tm.TestCase):
         tm.assert_isinstance(the_union, DatetimeIndex)
 
         # order does not matter
-        self.assert_(np.array_equal(right.union(left), the_union))
+        self.assert_numpy_array_equal(right.union(left), the_union)
 
         # overlapping, but different offset
         rng = date_range(START, END, freq=datetools.bmonthEnd)
@@ -228,7 +228,7 @@ class TestDateRange(tm.TestCase):
 
         the_join = left.join(right, how='outer')
         tm.assert_isinstance(the_join, DatetimeIndex)
-        self.assert_(the_join.freq is None)
+        self.assertIsNone(the_join.freq)
 
         # non-overlapping, no gap
         left = self.rng[:5]
@@ -242,20 +242,20 @@ class TestDateRange(tm.TestCase):
 
         the_join = self.rng.join(rng, how='outer')
         tm.assert_isinstance(the_join, DatetimeIndex)
-        self.assert_(the_join.freq is None)
+        self.assertIsNone(the_join.freq)
 
     def test_union_not_cacheable(self):
         rng = date_range('1/1/2000', periods=50, freq=datetools.Minute())
         rng1 = rng[10:]
         rng2 = rng[:25]
         the_union = rng1.union(rng2)
-        self.assert_(the_union.equals(rng))
+        self.assertTrue(the_union.equals(rng))
 
         rng1 = rng[10:]
         rng2 = rng[15:35]
         the_union = rng1.union(rng2)
         expected = rng[10:]
-        self.assert_(the_union.equals(expected))
+        self.assertTrue(the_union.equals(expected))
 
     def test_intersection(self):
         rng = date_range('1/1/2000', periods=50, freq=datetools.Minute())
@@ -263,24 +263,24 @@ class TestDateRange(tm.TestCase):
         rng2 = rng[:25]
         the_int = rng1.intersection(rng2)
         expected = rng[10:25]
-        self.assert_(the_int.equals(expected))
+        self.assertTrue(the_int.equals(expected))
         tm.assert_isinstance(the_int, DatetimeIndex)
-        self.assert_(the_int.offset == rng.offset)
+        self.assertEqual(the_int.offset, rng.offset)
 
         the_int = rng1.intersection(rng2.view(DatetimeIndex))
-        self.assert_(the_int.equals(expected))
+        self.assertTrue(the_int.equals(expected))
 
         # non-overlapping
         the_int = rng[:10].intersection(rng[10:])
         expected = DatetimeIndex([])
-        self.assert_(the_int.equals(expected))
+        self.assertTrue(the_int.equals(expected))
 
     def test_intersection_bug(self):
         # GH #771
         a = bdate_range('11/30/2011', '12/31/2011')
         b = bdate_range('12/10/2011', '12/20/2011')
         result = a.intersection(b)
-        self.assert_(result.equals(b))
+        self.assertTrue(result.equals(b))
 
     def test_summary(self):
         self.rng.summary()
@@ -318,19 +318,19 @@ class TestDateRange(tm.TestCase):
     def test_identical(self):
         t1 = self.rng.copy()
         t2 = self.rng.copy()
-        self.assert_(t1.identical(t2))
+        self.assertTrue(t1.identical(t2))
 
         # name
         t1 = t1.rename('foo')
-        self.assert_(t1.equals(t2))
-        self.assert_(not t1.identical(t2))
+        self.assertTrue(t1.equals(t2))
+        self.assertFalse(t1.identical(t2))
         t2 = t2.rename('foo')
-        self.assert_(t1.identical(t2))
+        self.assertTrue(t1.identical(t2))
 
         # freq
         t2v = Index(t2.values)
-        self.assert_(t1.equals(t2v))
-        self.assert_(not t1.identical(t2v))
+        self.assertTrue(t1.equals(t2v))
+        self.assertFalse(t1.identical(t2v))
 
     def test_daterange_bug_456(self):
         # GH #456
@@ -352,7 +352,7 @@ class TestDateRange(tm.TestCase):
 
         start = datetime(2011, 1, 1)
         exp_values = [start + i * offset for i in range(5)]
-        self.assert_(np.array_equal(result, DatetimeIndex(exp_values)))
+        self.assert_numpy_array_equal(result, DatetimeIndex(exp_values))
 
     def test_range_tz(self):
         # GH 2906
@@ -363,19 +363,19 @@ class TestDateRange(tm.TestCase):
         end = datetime(2011, 1, 3, tzinfo=tz('US/Eastern'))
 
         dr = date_range(start=start, periods=3)
-        self.assert_(dr.tz == tz('US/Eastern'))
-        self.assert_(dr[0] == start)
-        self.assert_(dr[2] == end)
+        self.assertEqual(dr.tz, tz('US/Eastern'))
+        self.assertEqual(dr[0], start)
+        self.assertEqual(dr[2], end)
 
         dr = date_range(end=end, periods=3)
-        self.assert_(dr.tz == tz('US/Eastern'))
-        self.assert_(dr[0] == start)
-        self.assert_(dr[2] == end)
+        self.assertEqual(dr.tz, tz('US/Eastern'))
+        self.assertEqual(dr[0], start)
+        self.assertEqual(dr[2], end)
 
         dr = date_range(start=start, end=end)
-        self.assert_(dr.tz == tz('US/Eastern'))
-        self.assert_(dr[0] == start)
-        self.assert_(dr[2] == end)
+        self.assertEqual(dr.tz, tz('US/Eastern'))
+        self.assertEqual(dr[0], start)
+        self.assertEqual(dr[2], end)
 
     def test_month_range_union_tz(self):
         _skip_if_no_pytz()
@@ -405,8 +405,8 @@ class TestDateRange(tm.TestCase):
             expected_left = closed[:-1]
             expected_right = closed[1:]
 
-            self.assert_(expected_left.equals(left))
-            self.assert_(expected_right.equals(right))
+            self.assertTrue(expected_left.equals(left))
+            self.assertTrue(expected_right.equals(right))
 
 
 class TestCustomDateRange(tm.TestCase):
@@ -445,13 +445,13 @@ class TestCustomDateRange(tm.TestCase):
         d = self.rng[10]
 
         comp = self.rng > d
-        self.assert_(comp[11])
-        self.assert_(not comp[9])
+        self.assertTrue(comp[11])
+        self.assertFalse(comp[9])
 
     def test_copy(self):
         cp = self.rng.copy()
         repr(cp)
-        self.assert_(cp.equals(self.rng))
+        self.assertTrue(cp.equals(self.rng))
 
     def test_repr(self):
         # only really care that it works
@@ -459,47 +459,47 @@ class TestCustomDateRange(tm.TestCase):
 
     def test_getitem(self):
         smaller = self.rng[:5]
-        self.assert_(np.array_equal(smaller, self.rng.view(np.ndarray)[:5]))
-        self.assertEquals(smaller.offset, self.rng.offset)
+        self.assert_numpy_array_equal(smaller, self.rng.view(np.ndarray)[:5])
+        self.assertEqual(smaller.offset, self.rng.offset)
 
         sliced = self.rng[::5]
-        self.assertEquals(sliced.offset, datetools.cday * 5)
+        self.assertEqual(sliced.offset, datetools.cday * 5)
 
         fancy_indexed = self.rng[[4, 3, 2, 1, 0]]
-        self.assertEquals(len(fancy_indexed), 5)
+        self.assertEqual(len(fancy_indexed), 5)
         tm.assert_isinstance(fancy_indexed, DatetimeIndex)
-        self.assert_(fancy_indexed.freq is None)
+        self.assertIsNone(fancy_indexed.freq)
 
         # 32-bit vs. 64-bit platforms
-        self.assertEquals(self.rng[4], self.rng[np.int_(4)])
+        self.assertEqual(self.rng[4], self.rng[np.int_(4)])
 
     def test_getitem_matplotlib_hackaround(self):
         values = self.rng[:, None]
         expected = self.rng.values[:, None]
-        self.assert_(np.array_equal(values, expected))
+        self.assert_numpy_array_equal(values, expected)
 
     def test_shift(self):
         shifted = self.rng.shift(5)
-        self.assertEquals(shifted[0], self.rng[5])
-        self.assertEquals(shifted.offset, self.rng.offset)
+        self.assertEqual(shifted[0], self.rng[5])
+        self.assertEqual(shifted.offset, self.rng.offset)
 
         shifted = self.rng.shift(-5)
-        self.assertEquals(shifted[5], self.rng[0])
-        self.assertEquals(shifted.offset, self.rng.offset)
+        self.assertEqual(shifted[5], self.rng[0])
+        self.assertEqual(shifted.offset, self.rng.offset)
 
         shifted = self.rng.shift(0)
-        self.assertEquals(shifted[0], self.rng[0])
-        self.assertEquals(shifted.offset, self.rng.offset)
+        self.assertEqual(shifted[0], self.rng[0])
+        self.assertEqual(shifted.offset, self.rng.offset)
 
         rng = date_range(START, END, freq=datetools.bmonthEnd)
         shifted = rng.shift(1, freq=datetools.cday)
-        self.assertEquals(shifted[0], rng[0] + datetools.cday)
+        self.assertEqual(shifted[0], rng[0] + datetools.cday)
 
     def test_pickle_unpickle(self):
         pickled = pickle.dumps(self.rng)
         unpickled = pickle.loads(pickled)
 
-        self.assert_(unpickled.offset is not None)
+        self.assertIsNotNone(unpickled.offset)
 
     def test_union(self):
         # overlapping
@@ -524,7 +524,7 @@ class TestCustomDateRange(tm.TestCase):
         tm.assert_isinstance(the_union, DatetimeIndex)
 
         # order does not matter
-        self.assert_(np.array_equal(right.union(left), the_union))
+        self.assert_numpy_array_equal(right.union(left), the_union)
 
         # overlapping, but different offset
         rng = date_range(START, END, freq=datetools.bmonthEnd)
@@ -548,7 +548,7 @@ class TestCustomDateRange(tm.TestCase):
 
         the_join = left.join(right, how='outer')
         tm.assert_isinstance(the_join, DatetimeIndex)
-        self.assert_(the_join.freq is None)
+        self.assertIsNone(the_join.freq)
 
         # non-overlapping, no gap
         left = self.rng[:5]
@@ -562,14 +562,14 @@ class TestCustomDateRange(tm.TestCase):
 
         the_join = self.rng.join(rng, how='outer')
         tm.assert_isinstance(the_join, DatetimeIndex)
-        self.assert_(the_join.freq is None)
+        self.assertIsNone(the_join.freq)
 
     def test_intersection_bug(self):
         # GH #771
         a = cdate_range('11/30/2011', '12/31/2011')
         b = cdate_range('12/10/2011', '12/20/2011')
         result = a.intersection(b)
-        self.assert_(result.equals(b))
+        self.assertTrue(result.equals(b))
 
     def test_summary(self):
         self.rng.summary()
@@ -616,26 +616,26 @@ class TestCustomDateRange(tm.TestCase):
     def test_cdaterange(self):
         rng = cdate_range('2013-05-01', periods=3)
         xp = DatetimeIndex(['2013-05-01', '2013-05-02', '2013-05-03'])
-        self.assert_(xp.equals(rng))
+        self.assertTrue(xp.equals(rng))
 
     def test_cdaterange_weekmask(self):
         rng = cdate_range('2013-05-01', periods=3,
                           weekmask='Sun Mon Tue Wed Thu')
         xp = DatetimeIndex(['2013-05-01', '2013-05-02', '2013-05-05'])
-        self.assert_(xp.equals(rng))
+        self.assertTrue(xp.equals(rng))
 
     def test_cdaterange_holidays(self):
         rng = cdate_range('2013-05-01', periods=3,
                           holidays=['2013-05-01'])
         xp = DatetimeIndex(['2013-05-02', '2013-05-03', '2013-05-06'])
-        self.assert_(xp.equals(rng))
+        self.assertTrue(xp.equals(rng))
 
     def test_cdaterange_weekmask_and_holidays(self):
         rng = cdate_range('2013-05-01', periods=3,
                           weekmask='Sun Mon Tue Wed Thu',
                           holidays=['2013-05-01'])
         xp = DatetimeIndex(['2013-05-02', '2013-05-05', '2013-05-06'])
-        self.assert_(xp.equals(rng))
+        self.assertTrue(xp.equals(rng))
 
 
 if __name__ == '__main__':
